;; Step-gradients/theme.jl

;; Copyright (C) 1999 Michele Campeotto <golia@supereva.it>

;; This theme is based on Window Maker, another window manager for X11
;; (wich is based on Apple NeXTStep), I ported it to Sawmill because I liked
;; his look'n'feel but Window Maker is'nt working well with Gnome.

(require 'gradient)

;; --- Frame preferences ---------------------------------------------------

(defgroup Step-gradients-frame "Step-gradients theme"
  :group appearance)

(defcustom Step-gradients:title-alignement 'right
  "Alignement of the text in the titlebar - needs restart -"
  :group (appearance Step-gradients-frame)
  :type symbol
  :options (left center right)
  :after-set after-setting-frame-option)

(defcustom Step-gradients:flat-buttons nil
  "Use flat buttons on titlebar - needs restart -"
  :group (appearance Step-gradients-frame)
  :type boolean
  :after-set after-setting-frame-option)

(defcustom Step-gradients:titlebar-active-color (get-color "#3fff3fff3fff")
  "Color of the active window titlebar"
  :group (appearance Step-gradients-frame)
  :type color
  :after-set after-setting-frame-option)

(defcustom Step-gradients:titlebar-inactive-color (get-color "#bffebffebffe")
  "Color of inactive windows titlebars"
  :group (appearance Step-gradients-frame)
  :type color
  :after-set after-setting-frame-option)

(defcustom Step-gradients:title-active-color (get-color "#cccbe708ffff")
  "Color of the active window title"
  :group (appearance Step-gradients-frame)
  :type color
  :after-set after-setting-frame-option)

(defcustom Step-gradients:title-inactive-color (get-color "#000000005478")
  "Color of inactive windows titles"
  :group (appearance Step-gradients-frame)
  :type color
  :after-set after-setting-frame-option)

(defcustom Step-gradients:resizebar-active-color (get-color "gray75")
  "Color of the active window resizebar"
  :group (appearance Step-gradients-frame)
  :type color
  :after-set after-setting-frame-option)

(defcustom Step-gradients:resizebar-inactive-color (get-color "gray75")
  "Color of inactive windows resizebars"
  :group (appearance Step-gradients-frame)
  :type color
  :after-set after-setting-frame-option)

(defgroup Step-gradients-shadings "Step-gradients shadings"
  :group appearance)

(defcustom Step-gradients:titlebar-gradient-type 'horizontal
  "Type of the gradient for the titlebar"
  :group (appearance Step-gradients-shadings)
  :type symbol
  :options (none horizontal vertical diagonal)
  :after-set after-setting-frame-option)

(defcustom Step-gradients:titlebar-active-color2 (get-color "#10bb59ee9362")
  "Second color of the active window titlebar"
  :group (appearance Step-gradients-shadings)
  :type color
  :after-set after-setting-frame-option)

(defcustom Step-gradients:titlebar-inactive-color2 (get-color "#cccce665ffff")
  "Second color of inactive windows titlebars"
  :group (appearance Step-gradients-shadings)
  :type color
  :after-set after-setting-frame-option)

(defcustom Step-gradients:resizebar-gradient-type 'horizontal
  "Type of the gradient for the resizebar - Not implemented yet! -"
  :group (appearance Step-gradients-shadings)
  :type symbol
  :options (none horizontal vertical diagonal)
  :after-set after-setting-frame-option)

(defcustom Step-gradients:resizebar-active-color2 (get-color "gray75")
  "Second color of the active window resizebar - Not implemented yet! -"
  :group (appearance Step-gradients-shadings)
  :type color
  :after-set after-setting-frame-option)

(defcustom Step-gradients:resizebar-inactive-color2 (get-color "gray75")
  "Second color of inactive windows resizebars - Not implemented yet! -"
  :group (appearance Step-gradients-shadings)
  :type color
  :after-set after-setting-frame-option)

;; --- Frame definition ----------------------------------------------------

(let* (
	(title-font (get-font "-*-helvetica-bold-r-normal-*-12-*-*-*-*-*-*"))
	(title-colors (lambda () (list Step-gradients:title-inactive-color Step-gradients:title-active-color)))
	(titlebar-colors (lambda () (list Step-gradients:titlebar-inactive-color Step-gradients:titlebar-active-color)))
	(resizebar-colors (lambda () (list Step-gradients:resizebar-inactive-color Step-gradients:resizebar-active-color)))

	(titlebar-colors2
		(lambda ()
			(if (eq Step-gradients:titlebar-gradient-type 'none)
				(list Step-gradients:titlebar-inactive-color Step-gradients:titlebar-active-color)
				(list Step-gradients:titlebar-inactive-color2 Step-gradients:titlebar-active-color2)
			)
		)
	)

	(brighten-color 
		(lambda (color delta)
			(get-color-rgb
				(if (< (+ delta (car (color-rgb color))) 65535)
					(+ delta (car (color-rgb color)))
					65535)
				(if (< (+ delta (cadr (color-rgb color))) 65535)
					(+ delta (cadr (color-rgb color)))
					65535)
				(if (< (+ delta (car (cddr (color-rgb color)))) 65535)
					(+ delta (car (cddr (color-rgb color))))
					65535)
			)
		)
	)

	(darken-color 
		(lambda (color delta)
			(get-color-rgb
				(+ (if (< delta (car (color-rgb color)))
						(- delta) 0)
					(car (color-rgb color)))
				(+ (if (< delta (cadr (color-rgb color)))
						(- delta) 0)
					(cadr (color-rgb color)))
				(+ (if (< delta (car (cddr (color-rgb color))))
						(- delta) 0)
					(car (cddr (color-rgb color))))
			)
		)
	)

	(render-titlebar
		(lambda (img state)
			(apply
				(cond
					((eq Step-gradients:titlebar-gradient-type 'none)
						draw-horizontal-gradient)
					((eq Step-gradients:titlebar-gradient-type 'horizontal)
						draw-horizontal-gradient)
					((eq Step-gradients:titlebar-gradient-type 'vertical)
						draw-vertical-gradient)
					((eq Step-gradients:titlebar-gradient-type 'diagonal)
						draw-diagonal-gradient)
				)
				img
				(if state
					(if (eq Step-gradients:titlebar-gradient-type 'none)
						(list Step-gradients:titlebar-active-color Step-gradients:titlebar-active-color)
						(list Step-gradients:titlebar-active-color Step-gradients:titlebar-active-color2)
					)
					(if (eq Step-gradients:titlebar-gradient-type 'none)
						(list Step-gradients:titlebar-inactive-color Step-gradients:titlebar-inactive-color)
						(list Step-gradients:titlebar-inactive-color Step-gradients:titlebar-inactive-color2)
					)
				)
			)
		)
	)

	(render-titlebar-bevel-up
		(lambda (img state)
			(apply draw-horizontal-gradient img
				(if state
					(cond
						((eq Step-gradients:titlebar-gradient-type 'none)
							(list 
								(brighten-color Step-gradients:titlebar-active-color 22000)
								(brighten-color Step-gradients:titlebar-active-color 22000)
							))
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list 
								(brighten-color Step-gradients:titlebar-active-color 22000)
								(brighten-color Step-gradients:titlebar-active-color 22000)
							))
						(t
							(list
								(brighten-color Step-gradients:titlebar-active-color 22000)
								(brighten-color Step-gradients:titlebar-active-color2 22000)
							))
					)
					(cond
						((eq Step-gradients:titlebar-gradient-type 'none)
							(list
								(brighten-color Step-gradients:titlebar-inactive-color 22000)
								(brighten-color Step-gradients:titlebar-inactive-color 22000)
							))
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list 
								(brighten-color Step-gradients:titlebar-active-color 22000)
								(brighten-color Step-gradients:titlebar-active-color 22000)
							))
						(t
							(list
								(brighten-color Step-gradients:titlebar-inactive-color 22000)
								(brighten-color Step-gradients:titlebar-inactive-color2 22000)
							))
					)
				)
			)
		)
	)

	(render-titlebar-bevel-down
		(lambda (img state)
			(apply draw-horizontal-gradient img
				(if state
					(cond
						((eq Step-gradients:titlebar-gradient-type 'none)
							(list 
								(darken-color Step-gradients:titlebar-active-color 22000)
								(darken-color Step-gradients:titlebar-active-color 22000)
							))
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list 
								(darken-color Step-gradients:titlebar-active-color2 22000)
								(darken-color Step-gradients:titlebar-active-color2 22000)
							))
						(t
							(list
								(darken-color Step-gradients:titlebar-active-color 22000)
								(darken-color Step-gradients:titlebar-active-color2 22000)
							))
					)
					(cond
						((eq Step-gradients:titlebar-gradient-type 'none)
							(list
								(darken-color Step-gradients:titlebar-inactive-color 22000)
								(darken-color Step-gradients:titlebar-inactive-color 22000)
							))
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list 
								(darken-color Step-gradients:titlebar-inactive-color2 22000)
								(darken-color Step-gradients:titlebar-inactive-color2 22000)
							))
						(t
							(list
								(darken-color Step-gradients:titlebar-inactive-color 22000)
								(darken-color Step-gradients:titlebar-inactive-color2 22000)
							))
					)
				)
			)
		)
	)

	(render-minimize-button
		(lambda (img state)
			(apply
				(cond
					((eq Step-gradients:titlebar-gradient-type 'vertical)
						draw-vertical-gradient)
					(t
						draw-horizontal-gradient)
				)
				img
				(if state
					(cond
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list Step-gradients:titlebar-active-color Step-gradients:titlebar-active-color2))
						(t
							(list Step-gradients:titlebar-active-color Step-gradients:titlebar-active-color))
					)
					(cond
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list Step-gradients:titlebar-inactive-color Step-gradients:titlebar-inactive-color2))
						(t
							(list Step-gradients:titlebar-inactive-color Step-gradients:titlebar-inactive-color))
					)
				)
			)
		)
	)

	(render-minimize-left
		(lambda (img state)
			(apply
				(cond
					((eq Step-gradients:titlebar-gradient-type 'vertical)
						draw-vertical-gradient)
					(t
						draw-horizontal-gradient)
				)
				img
				(if state
					(cond
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list
								(brighten-color Step-gradients:titlebar-active-color 22000)
								(brighten-color Step-gradients:titlebar-active-color2 22000)
							))
						(t
							(list
								(brighten-color Step-gradients:titlebar-active-color 22000)
								(brighten-color Step-gradients:titlebar-active-color 22000)
							))
					)
					(cond
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list
								(brighten-color Step-gradients:titlebar-inactive-color 22000)
								(brighten-color Step-gradients:titlebar-inactive-color2 22000)
							))
						(t
							(list
								(brighten-color Step-gradients:titlebar-inactive-color 22000)
								(brighten-color Step-gradients:titlebar-inactive-color 22000)
							))
					)
				)
			)
		)
	)

	(render-minimize-right
		(lambda (img state)
			(apply
				(cond
					((eq Step-gradients:titlebar-gradient-type 'vertical)
						draw-vertical-gradient)
					(t
						draw-horizontal-gradient)
				)
				img
				(if state
					(cond
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list
								(darken-color Step-gradients:titlebar-active-color 22000)
								(darken-color Step-gradients:titlebar-active-color2 22000)
							))
						(t
							(list
								(darken-color Step-gradients:titlebar-active-color 22000)
								(darken-color Step-gradients:titlebar-active-color 22000)
							))
					)
					(cond
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list
								(darken-color Step-gradients:titlebar-inactive-color 22000)
								(darken-color Step-gradients:titlebar-inactive-color2 22000)
							))
						(t
							(list
								(darken-color Step-gradients:titlebar-inactive-color 22000)
								(darken-color Step-gradients:titlebar-inactive-color 22000)
							))
					)
				)
			)
		)
	)

	(render-close-button
		(lambda (img state)
			(apply
				(cond
					((eq Step-gradients:titlebar-gradient-type 'vertical)
						draw-vertical-gradient)
					(t
						draw-horizontal-gradient)
				)
				img
				(if state
					(cond
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list Step-gradients:titlebar-active-color Step-gradients:titlebar-active-color2))
						((eq Step-gradients:titlebar-gradient-type 'none)
							(list Step-gradients:titlebar-active-color Step-gradients:titlebar-active-color))
						(t
							(list Step-gradients:titlebar-active-color2 Step-gradients:titlebar-active-color2))
					)
					(cond
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list Step-gradients:titlebar-inactive-color Step-gradients:titlebar-inactive-color2))
						((eq Step-gradients:titlebar-gradient-type 'none)
							(list Step-gradients:titlebar-inactive-color Step-gradients:titlebar-inactive-color))
						(t
							(list Step-gradients:titlebar-inactive-color2 Step-gradients:titlebar-inactive-color2))
					)
				)
			)
		)
	)

	(render-close-left
		(lambda (img state)
			(apply
				(cond
					((eq Step-gradients:titlebar-gradient-type 'vertical)
						draw-vertical-gradient)
					(t
						draw-horizontal-gradient)
				)
				img
				(if state
					(cond
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list
								(brighten-color Step-gradients:titlebar-active-color 22000)
								(brighten-color Step-gradients:titlebar-active-color2 22000)
							))
						((eq Step-gradients:titlebar-gradient-type 'none)
							(list
								(brighten-color Step-gradients:titlebar-active-color 22000)
								(brighten-color Step-gradients:titlebar-active-color 22000)
							))
						(t
							(list
								(brighten-color Step-gradients:titlebar-active-color2 22000)
								(brighten-color Step-gradients:titlebar-active-color2 22000)
							))
					)
					(cond
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list
								(brighten-color Step-gradients:titlebar-inactive-color 22000)
								(brighten-color Step-gradients:titlebar-inactive-color2 22000)
							))
						((eq Step-gradients:titlebar-gradient-type 'none)
							(list
								(brighten-color Step-gradients:titlebar-inactive-color 22000)
								(brighten-color Step-gradients:titlebar-inactive-color 22000)
							))
						(t
							(list
								(brighten-color Step-gradients:titlebar-inactive-color2 22000)
								(brighten-color Step-gradients:titlebar-inactive-color2 22000)
							))
					)
				)
			)
		)
	)

	(render-close-right
		(lambda (img state)
			(apply
				(cond
					((eq Step-gradients:titlebar-gradient-type 'vertical)
						draw-vertical-gradient)
					(t
						draw-horizontal-gradient)
				)
				img
				(if state
					(cond
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list
								(darken-color Step-gradients:titlebar-active-color 22000)
								(darken-color Step-gradients:titlebar-active-color2 22000)
							))
						((eq Step-gradients:titlebar-gradient-type 'none)
							(list
								(darken-color Step-gradients:titlebar-active-color 22000)
								(darken-color Step-gradients:titlebar-active-color 22000)
							))
						(t
							(list
								(darken-color Step-gradients:titlebar-active-color2 22000)
								(darken-color Step-gradients:titlebar-active-color2 22000)
							))
					)
					(cond
						((eq Step-gradients:titlebar-gradient-type 'vertical)
							(list
								(darken-color Step-gradients:titlebar-inactive-color 22000)
								(darken-color Step-gradients:titlebar-inactive-color2 22000)
							))
						((eq Step-gradients:titlebar-gradient-type 'none)
							(list
								(darken-color Step-gradients:titlebar-inactive-color 22000)
								(darken-color Step-gradients:titlebar-inactive-color 22000)
							))
						(t
							(list
								(darken-color Step-gradients:titlebar-inactive-color2 22000)
								(darken-color Step-gradients:titlebar-inactive-color2 22000)
							))
					)
				)
			)
		)
	)

	(recolor-image
		(lambda (img color)
			(when (and (imagep img) (colorp color))
				(let*
					((rgb (color-rgb color))
					 (red (nth 0 rgb))
					 (green (nth 1 rgb))
					 (blue (nth 2 rgb)))
	    ;; use the color modifiers
				(set-image-modifier img nil '(255 255 255))
				(set-image-modifier img 'red (list (/ red 256) 255 (/ red 256)))
				(set-image-modifier img 'green (list (/ green 256) 255 (/ green 256)))
				(set-image-modifier img 'blue (list (/ blue 256) 255 (/ blue 256))))
			)
		)
	)

	(minimize-flat (list
		(recolor-image (make-image "minimize-flat-button.png")
			Step-gradients:title-inactive-color)
		(recolor-image (make-image "minimize-flat-button.png")
			Step-gradients:title-active-color) nil
		(make-image "minimize-flat-pressed.png")))

	(minimize-bevel (list
		(make-image "minimize-bevel-button.png")
		(make-image "minimize-bevel-button.png") nil
		(make-image "minimize-bevel-pressed.png")))

	(minimize (lambda ()
		(if Step-gradients:flat-buttons minimize-flat minimize-bevel)))

	(close-flat (list
		(recolor-image (make-image "close-flat-button.png")
			Step-gradients:title-inactive-color)
		(recolor-image (make-image "close-flat-button.png")
			Step-gradients:title-active-color) nil
		(make-image "close-flat-pressed.png")))

	(close-bevel (list
		(make-image "close-bevel-button.png")
		(make-image "close-bevel-button.png") nil
		(make-image "close-bevel-pressed.png")))

	(close (lambda ()
		(if Step-gradients:flat-buttons close-flat close-bevel)))

	(border-color (get-color "black"))

	(bevel-up-left-color (list 
		(brighten-color Step-gradients:titlebar-inactive-color 22000)
		(brighten-color Step-gradients:titlebar-active-color 22000)))
	(bevel-down-right-color (list
		(darken-color Step-gradients:titlebar-inactive-color 22000)
		(darken-color Step-gradients:titlebar-active-color 22000)))

	(bevel-resize-up-left-color (list
		(brighten-color Step-gradients:resizebar-inactive-color 22000)
		(brighten-color Step-gradients:resizebar-active-color 22000)))
	(bevel-resize-down-right-color (list
		(darken-color Step-gradients:resizebar-inactive-color 22000)
		(darken-color Step-gradients:resizebar-active-color 22000)))

;; --- Frame parts ------------------------
;; Titlebar black border
	(black-left `(
		(background . ,border-color)
		(left-edge . -1)
		(width . 1)
		(top-edge . -23)
		(height . 23)))
	(black-right `(
		(background . ,border-color)
		(right-edge . -1)
		(width . 1)
		(top-edge . -23)
		(height . 23)))
	(black-top `(
		(background . ,border-color)
		(right-edge . -1)
		(left-edge . -1)
		(top-edge . -23)
		(height . 1)))
	(black-bottom `(
		(background . ,border-color)
		(right-edge . -1)
		(left-edge . -1)
		(top-edge . -1)
		(height . 1)))
;; Title bevel border
	(bevel-left `(
		(renderer . ,render-minimize-left)
		(left-edge . 0)
		(width . 1)
		(top-edge . -22)
		(height . 21)))
	(bevel-top `(
		(renderer . ,render-titlebar-bevel-up)
		(right-edge . 0)
		(left-edge . 0)
		(top-edge . -22)
		(height . 1)))
	(bevel-right `(
;;		(background . ,bevel-down-right-color)
		(renderer . ,render-close-right)
		(right-edge . 0)
		(width . 1)
		(top-edge . -22)
		(height . 21)))
	(bevel-bottom `(
		(renderer . ,render-titlebar-bevel-down)
		(right-edge . 0)
		(left-edge . 1)
		(top-edge . -2)
		(height . 1)))

;; Titlebar
	(titlebar `(
		(renderer . ,render-titlebar)
		(foreground . ,title-colors)
		(font . ,title-font)
		(text . ,window-name)
		(x-justify . ,Step-gradients:title-alignement)
		(y-justify . center)
		(left-edge . ,(if Step-gradients:flat-buttons 23 20))
		(right-edge . ,(if Step-gradients:flat-buttons 23 20))
		(top-edge . -21)
		(height . 19)
		(cursor . left_ptr)
		(class . title))
	)

;; Transient window titlebar
	(transient-titlebar `(
		(renderer . ,render-titlebar)
		(foreground . ,title-colors)
		(font . ,title-font)
		(text . ,window-name)
		(x-justify . ,Step-gradients:title-alignement)
		(y-justify . center)
		(left-edge . 1)
		(right-edge . ,(if Step-gradients:flat-buttons 23 20))
		(top-edge . -21)
		(height . 19)
		(cursor . left_ptr)
		(class . title)))

;; Minimize button right border
	(button-border-11 
		(if Step-gradients:flat-buttons `(
			(renderer . ,render-minimize-right)
			(left-edge . 20)
			(width . 1)
			(top-edge . -21)
			(height . 20))
			nil))
	(button-border-12
		(if Step-gradients:flat-buttons `(
			(background . ,border-color)
			(left-edge . 21)
			(width . 1)
			(top-edge . -22)
			(height . 21))
			nil))
	(button-border-13
		(if Step-gradients:flat-buttons `(
			(renderer . ,render-minimize-left)
			(left-edge . 22)
			(width . 1)
			(top-edge . -22)
			(height . 21))
			nil))

;; Minimize button icon
	(minimize `(
		(renderer . ,render-minimize-button)
		(foreground . ,minimize)
		(left-edge . 1)
		(width . 19)
		(top-edge . -21)
		(height . 19)
		(cursor . left_ptr)
		(class . iconify-button)))

;; Close button left border
	(button-border-21 
		(if Step-gradients:flat-buttons `(
;;			(background . ,bevel-down-right-color)
			(renderer . ,render-close-right)
			(right-edge . 22)
			(width . 1)
			(top-edge . -21)
			(height . 20))
			nil))
	(button-border-22
		(if Step-gradients:flat-buttons `(
			(background . ,border-color)
			(right-edge . 21)
			(width . 1)
			(top-edge . -22)
			(height . 21))
			nil))
	(button-border-23
		(if Step-gradients:flat-buttons `(
;;			(background . ,bevel-up-left-color)
			(renderer . ,render-close-left)
			(right-edge . 20)
			(width . 1)
			(top-edge . -22)
			(height . 21))
			nil))

;; Close button icon
	(close `(
		(renderer . ,render-close-button)
		(foreground . ,close)
		(right-edge . 1)
		(width . 19)
		(top-edge . -21)
		(height . 19)
		(cursor . left_ptr)
		(class . close-button))
	)

;; Left border
	(left-border `(
		(background . ,border-color)
		(right-edge . -1)
		(width . 1)
		(top-edge . 0)
		(bottom-edge . -1)
		(cursor . left_ptr)
		(class . right-border)))

;;Right border
	(right-border `(
		(background . ,border-color)
		(left-edge . -1)
		(width . 1)
		(top-edge . 0)
		(bottom-edge . -1)
		(cursor . left_ptr)
		(class . left-border)))

;; --- Frame definition -------------------

;; Normal window frame
	(frame `(
		,black-left
		,black-right
		,black-top
		,black-bottom
		,bevel-left
		,bevel-right
		,bevel-top
		,bevel-bottom
		,titlebar
		,button-border-11
		,button-border-12
		,button-border-13
		,minimize
		,button-border-21
		,button-border-22
		,button-border-23
		,close
		,left-border
		,right-border
	;; Bottom left corner
		((background . ,border-color)
		 (left-edge . -1)
		 (width . 1)
		 (bottom-edge . -9)
		 (height . 9)
		 (cursor . left_ptr)
		 (class . left-border))
		((background . ,bevel-resize-down-right-color)
		 (left-edge . 29)
		 (width . 1)
		 (bottom-edge . -8)
		 (height . 6))
		((background . ,bevel-resize-up-left-color)
		 (left-edge . 30)
		 (width . 1)
		 (bottom-edge . -8)
		 (height . 6))
		((background . ,resizebar-colors)
		 (left-edge . 0)
		 (width . 29)
		 (bottom-edge . -8)
		 (height . 6)
		 (cursor . left_ptr)
		 (class . bottom-left-corner))
	;; Bottom border
		((background . ,bevel-resize-down-right-color)
		 (right-edge . 0)
		 (left-edge . 0)
		 (bottom-edge . -1)
		 (height . 1))
		((background . ,bevel-resize-up-left-color)
		 (right-edge . 0)
		 (left-edge . 0)
		 (bottom-edge . -2)
		 (height . 1))
		((background . ,border-color)
		 (right-edge . -1)
		 (left-edge . -1)
		 (bottom-edge . -9)
		 (height . 1))
		((background . ,resizebar-colors)
		 (left-edge . 31)
		 (right-edge . 31)
		 (bottom-edge . -8)
		 (height . 6)
		 (cursor . left_ptr)
		 (class . bottom-border))
	;; Bottom right corner
		((background . ,border-color)
		 (right-edge . -1)
		 (width . 1)
		 (bottom-edge . -9)
		 (height . 9)
		 (cursor . left_ptr)
		 (class . left-border))
		((background . ,bevel-resize-down-right-color)
		 (right-edge . 30)
		 (width . 1)
		 (bottom-edge . -8)
		 (height . 6))
		((background . ,bevel-resize-up-left-color)
         (right-edge . 29)
		 (width . 1)
		 (bottom-edge . -8)
		 (height . 6))
		((background . ,resizebar-colors)
		 (right-edge . 0)
		 (width . 29)
		 (bottom-edge . -8)
		 (height . 6)
		 (cursor . left_ptr)
		 (class . bottom-right-corner))
	)) ;; end frame

;; Normal window shaded frame
	(shaped-frame `(
		,black-left
		,black-right
		,black-top
		,black-bottom
		,bevel-left
		,bevel-right
		,bevel-top
		,bevel-bottom
		,titlebar
		,button-border-11
		,button-border-12
		,button-border-13
		,minimize
		,button-border-21
		,button-border-22
		,button-border-23
		,close
	)) ;; end shaped-frame

;; Dialog window frame
	(transient-frame `(
		,black-left
		,black-right
		,black-top
		,black-bottom
		,bevel-left
		,bevel-right
		,bevel-top
		,bevel-bottom
		,transient-titlebar
		,button-border-21
		,button-border-22
		,button-border-23
		,close
		,left-border
		,right-border
	;; Bottom border
		((background . ,border-color)
		 (left-edge . 0)
		 (right-edge . 0)
		 (bottom-edge . -1)
		 (height . 1)
		 (cursor . left_ptr)
		 (class . bottom-border))
	)) ;; end transient-frame

;; Dialog window shaded frame
	(shaped-transient-frame `(
		,black-left
		,black-right
		,black-top
		,black-bottom
		,bevel-left
		,bevel-right
		,bevel-top
		,bevel-bottom
		,transient-titlebar
		,button-border-21
		,button-border-22
		,button-border-23
		,close
	))) ;; end shaped-transient-frame

	(add-frame-style 'Step-gradients
		(lambda (w type)
			(cond
				((eq type 'shaped) shaped-frame)
				((eq type 'transient) transient-frame)
				((eq type 'shaped-transient) shaped-transient-frame)
				((eq type 'unframed) nil)
				(t frame))
		)
	)
)
